Class: Doorkeeper::OpenidConnect::Config::Builder
- Inherits:
-
Object
- Object
- Doorkeeper::OpenidConnect::Config::Builder
- Defined in:
- lib/doorkeeper/openid_connect/config.rb
Instance Method Summary collapse
- #build ⇒ Object
-
#initialize(&block) ⇒ Builder
constructor
A new instance of Builder.
- #jws_private_key(*args) ⇒ Object
- #jws_public_key(*_args) ⇒ Object
Constructor Details
Instance Method Details
#build ⇒ Object
25 26 27 |
# File 'lib/doorkeeper/openid_connect/config.rb', line 25 def build @config end |
#jws_private_key(*args) ⇒ Object
33 34 35 36 |
# File 'lib/doorkeeper/openid_connect/config.rb', line 33 def jws_private_key(*args) warn "DEPRECATION WARNING: `jws_private_key` has been replaced by `signing_key` and will be removed in a future version, please remove it from config/initializers/doorkeeper_openid_connect.rb" signing_key(*args) end |
#jws_public_key(*_args) ⇒ Object
29 30 31 |
# File 'lib/doorkeeper/openid_connect/config.rb', line 29 def jws_public_key(*_args) warn "DEPRECATION WARNING: `jws_public_key` is not needed anymore and will be removed in a future version, please remove it from config/initializers/doorkeeper_openid_connect.rb" end |